import {
    IonPage,
    IonContent,
    IonHeader,
    IonTitle,
    IonToolbar,
    IonFooter,
    IonNavLink,
    IonButton,
    IonImg,
    IonGrid,
    IonRow,
    IonCol,
    IonButtons,
    IonBackButton,
    useIonViewWillEnter
} from '@ionic/react';
import { useParams } from 'react-router';
import React, { useState } from 'react';
import { BioInfo, getMessage } from '../data/BioInfo';
import './Biography.css';
import Questions from './Questions';
import EnciclopediaPR from '../assets/EnciclopediaPR.png';
import RobertoClemente from '../assets/RobertoClemente.jpg';

const Biography: React.FC = () => {
    const [bioinfo, setMessage] = useState<BioInfo>();
    const params = useParams<{ id: string }>();

    useIonViewWillEnter(() => {
        const msg = getMessage(parseInt(params.id, 10));
        setMessage(msg);
    });

    return (
        <IonPage>
            <IonHeader>
                <IonToolbar>
                    <IonGrid fixed={true}>
                        <IonRow>
                            <IonCol></IonCol>
                            <IonCol>
                                <IonImg style={{ height: 50, width: 100 }} src={EnciclopediaPR} alt='Logo'></IonImg>
                                <IonTitle>Biografía</IonTitle>
                            </IonCol>
                            <IonCol></IonCol>
                        </IonRow>
                    </IonGrid>
                </IonToolbar>
            </IonHeader>
            <IonContent fullscreen className="ion-padding">
                {bioinfo ? (
                    <>
                        <IonImg style={{ height: 300, width: 600 }} src={RobertoClemente} alt='Logo'></IonImg>
                        <h1>{bioinfo.title}</h1>

                        <p>{bioinfo.tags}</p>
                        <p>{bioinfo.Text1}</p>
                        <p>{bioinfo.Text2}</p>
                        <IonNavLink routerDirection="forward" component={() => <Questions />}>
                            <IonButton>Tomar quiz</IonButton>
                        </IonNavLink>
                    </>
                ) : (
                    <div>Message not found</div>
                )}
            </IonContent>

            <IonFooter>
                <IonToolbar>
                    <IonButtons slot="start">
                        <IonBackButton defaultHref="/home"></IonBackButton>
                    </IonButtons>
                </IonToolbar>
            </IonFooter>
        </IonPage>
    );
};

export default Biography;